==> gorilla-notebook-0.4.12.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.storage.direct.gist.js <==
goog.provide('pinkgorilla.storage.direct.gist');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.storage.direct.direct');
goog.require('pinkgorilla.storage.gist');
(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$direct$Direct$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$direct$Direct$load_url$arity$2 = (function (self,base_path){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.direct.gist","/tmp/form-init98329900837026950.clj",11,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["gist-storage.load-url for storage settings",self__$1], null);
}),null)),null,-1802532105);

return ["https://api.github.com/gists/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.id)].join('');
}));

(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$direct$Direct$decode_content$arity$2 = (function (self,response){
var self__$1 = this;
var files = cljs.core.get.cljs$core$IFn$_invoke$arity$2(response,"files");
var name = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((1),cljs.core.count(files)))?cljs.core.first(cljs.core.keys(files)):self__$1.filename);
var content = cljs.core.get.cljs$core$IFn$_invoke$arity$2(cljs.core.get.cljs$core$IFn$_invoke$arity$2(files,name),"content");
return content;
}));

//# sourceMappingURL=pinkgorilla.storage.direct.gist.js.map

==> gorilla-notebook-0.4.13.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.storage.direct.gist.js <==
goog.provide('pinkgorilla.storage.direct.gist');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.storage.direct.direct');
goog.require('pinkgorilla.storage.gist');
(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$direct$Direct$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$direct$Direct$load_url$arity$2 = (function (self,base_path){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.direct.gist","/tmp/form-init1849199092361317681.clj",11,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["gist-storage.load-url for storage settings",self__$1], null);
}),null)),null,262851545);

return ["https://api.github.com/gists/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.id)].join('');
}));

(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$direct$Direct$decode_content$arity$2 = (function (self,response){
var self__$1 = this;
var files = cljs.core.get.cljs$core$IFn$_invoke$arity$2(response,"files");
var name = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((1),cljs.core.count(files)))?cljs.core.first(cljs.core.keys(files)):self__$1.filename);
var content = cljs.core.get.cljs$core$IFn$_invoke$arity$2(cljs.core.get.cljs$core$IFn$_invoke$arity$2(files,name),"content");
return content;
}));

//# sourceMappingURL=pinkgorilla.storage.direct.gist.js.map
